==> py-martel-0.3.5%2C1.tgz: lib/python2.0/site-packages/Martel/formats/prosite16.py <==
"""Parser for the Prosite 16.0 format."""
import Martel
from Martel import RecordReader

def Simple(tag, tag_data):
    return Martel.Group(tag, Martel.Str(tag + "   ") +
                        Martel.Group(tag_data, Martel.Re("[^\n]*")) +
                        Martel.Str("\n")
                        )

#--- ID  Identification                     (Begins each entry; 1 per entry)
ID = Martel.Group("ID", Martel.Re(
    r"ID   (?P<entry_name>\w+);\s+(?P<entry_type>\w+)\.\n"))
                  
#--- AC  Accession number                   (1 per entry)
AC = Martel.Group("AC", Martel.Re(r"AC   (?P<ac_number>\w+);\n"))

#--- DT  Date                               (1 per entry)
# ID   PTS_EIIA_2; PATTERN. has a 5 digit date!
DT = Martel.Group("DT", Martel.Re(
    r"DT   (?P<created>(?P<month>...)-(?P<year>\d{4}) \(CREATED\)); "
    r"(?P<data_update>(?P<month>...)-(?P<year>\d{4}) \(DATA UPDATE\)); "
    r"(?P<info_update>(?P<month>...)-(?P<year>\d{4,5}) \(INFO UPDATE\))\.\n"))

#--- DE  Short description                  (1 per entry)
DE = Simple("DE", "description")

#--- PA  Pattern                            (>=0 per entry)
PA = Simple("PA", "pattern")
PA_block1 = Martel.Group("PA_block", Martel.Rep1(PA))
    
#--- MA  Matrix/profile                     (>=0 per entry)
MA = Simple("MA", "data")
MA_block1 = Martel.Group("MA_block", Martel.Rep1(MA))
MA_block = Martel.Opt(MA_block1)

#--- RU  Rule                               (>=0 per entry)
RU = Simple("RU", "rule")
RU_block1 = Martel.Group("RU_block", Martel.Rep1(RU))
RU_block = Martel.Opt(RU_block1)

#--- NR  Numerical results                  (>=0 per entry)
NR = Simple("NR", "results")
NR_block = Martel.Opt(Martel.Group("NR_block", Martel.Rep1(NR)))

#--- CC  Comments                           (>=0 per entry)
CC = Simple("CC", "comment")
CC_block = Martel.Opt(Martel.Group("CC_block", Martel.Rep1(CC)))

#--- DR  Cross-references to SWISS-PROT     (>=0 per entry)
DR = Simple("DR", "reference")
DR_block = Martel.Opt(Martel.Group("DR_block", Martel.Rep1(DR)))

#--- 3D  Cross-references to PDB            (>=0 per entry)
x3D = Martel.Group("_3D", Martel.Re("3D   (?P<_3D>[^\n]*)\n"))
x3D_block = Martel.Opt(Martel.Group("_3D_block", Martel.Rep1(x3D)))

#--- DO  Pointer to the documentation file  (1 per entry)
DO = Martel.Group("DO", Martel.Re(r"DO   (?P<pdoc>PDOC\d{5});\n"))

#--- //  Termination line                   (Ends each entry; 1 per entry)
end = Martel.Group("END", Martel.Str("//\n"))

# The CC lines in the copyright do not all start "CC   ", despite the
# claims made in the documentation!
copyright = Martel.Group("copyright",
                         Martel.Rep(Martel.Group("CC",
                                                 Martel.Re(r"CC[^\n]*\n"))
                                    ) + \
                         Martel.Str("//\n"))

record = Martel.Group("prosite_record",
                      ID + \
                      AC + \
                      DT + \
                      DE + \
                      (PA_block1 + RU_block |
                       MA_block1 + CC_block + MA_block |
                       RU_block1) + \
                      NR_block + \
                      CC_block + \
                      DR_block + \
                      CC_block + \
                      DR_block + \
                      x3D_block + \
                      DO + \
                      x3D_block + \
                      end)

format = Martel.HeaderFooter("prosite16",
                             copyright, RecordReader.EndsWith, ("//\n", ),
                             record, RecordReader.EndsWith, ("//\n", ),
                             None, None, None)

==> py-martel-0.5_2%2C1.tgz: lib/python2.0/site-packages/Martel/formats/prosite16.py <==
"""Parser for the Prosite 16.0 format."""
import Martel
from Martel import RecordReader

def Simple(tag, tag_data):
    return Martel.Group(tag, Martel.Str(tag + "   ") +
                        Martel.ToEol(tag_data)
                        )

#--- ID  Identification                     (Begins each entry; 1 per entry)
ID = Martel.Group("ID", Martel.Re(
    r"ID   (?P<entry_name>\w+);\s+(?P<entry_type>\w+)\.\R"))
                  
#--- AC  Accession number                   (1 per entry)
AC = Martel.Group("AC", Martel.Re(r"AC   (?P<ac_number>\w+);\R"))

#--- DT  Date                               (1 per entry)
# ID   PTS_EIIA_2; PATTERN. has a 5 digit date!
DT = Martel.Group("DT", Martel.Re(
    r"DT   (?P<created>(?P<month>...)-(?P<year>\d{4}) \(CREATED\)); "
    r"(?P<data_update>(?P<month>...)-(?P<year>\d{4}) \(DATA UPDATE\)); "
    r"(?P<info_update>(?P<month>...)-(?P<year>\d{4,5}) \(INFO UPDATE\))\.\R"))

#--- DE  Short description                  (1 per entry)
DE = Simple("DE", "description")

#--- PA  Pattern                            (>=0 per entry)
PA = Simple("PA", "pattern")
PA_block1 = Martel.Group("PA_block", Martel.Rep1(PA))
    
#--- MA  Matrix/profile                     (>=0 per entry)
MA = Simple("MA", "data")
MA_block1 = Martel.Group("MA_block", Martel.Rep1(MA))
MA_block = Martel.Opt(MA_block1)

#--- RU  Rule                               (>=0 per entry)
RU = Simple("RU", "rule")
RU_block1 = Martel.Group("RU_block", Martel.Rep1(RU))
RU_block = Martel.Opt(RU_block1)

#--- NR  Numerical results                  (>=0 per entry)
NR = Simple("NR", "results")
NR_block = Martel.Opt(Martel.Group("NR_block", Martel.Rep1(NR)))

#--- CC  Comments                           (>=0 per entry)
CC = Simple("CC", "comment")
CC_block = Martel.Opt(Martel.Group("CC_block", Martel.Rep1(CC)))

#--- DR  Cross-references to SWISS-PROT     (>=0 per entry)
DR = Simple("DR", "reference")
DR_block = Martel.Opt(Martel.Group("DR_block", Martel.Rep1(DR)))

#--- 3D  Cross-references to PDB            (>=0 per entry)
x3D = Martel.Group("_3D", Martel.Re("3D   (?P<_3D>[^\R]*)\R"))
x3D_block = Martel.Opt(Martel.Group("_3D_block", Martel.Rep1(x3D)))

#--- DO  Pointer to the documentation file  (1 per entry)
DO = Martel.Group("DO", Martel.Re(r"DO   (?P<pdoc>PDOC\d{5});\R"))

#--- //  Termination line                   (Ends each entry; 1 per entry)
end = Martel.Group("END", Martel.Str("//") + Martel.AnyEol())

# The CC lines in the copyright do not all start "CC   ", despite the
# claims made in the documentation!
copyright = Martel.Group("copyright",
                         Martel.Rep(Martel.Group("CC",
                                                 Martel.Re(r"CC[^\R]*\R"))
                                    ) + \
                         Martel.Str("//") + Martel.AnyEol())

record = Martel.Group("prosite_record",
                      ID + \
                      AC + \
                      DT + \
                      DE + \
                      (PA_block1 + RU_block |
                       MA_block1 + CC_block + MA_block |
                       RU_block1) + \
                      NR_block + \
                      CC_block + \
                      DR_block + \
                      CC_block + \
                      DR_block + \
                      x3D_block + \
                      DO + \
                      x3D_block + \
                      end)

format = Martel.HeaderFooter("prosite16",
                             copyright, RecordReader.EndsWith, ("//\n", ),
                             record, RecordReader.EndsWith, ("//\n", ),
                             None, None, None)
